@@ -1,16 +1,15 @@
 package VM::JiffyBox::Box;
 {
-  $VM::JiffyBox::Box::VERSION = '0.007'; # TRIAL
+  $VM::JiffyBox::Box::VERSION = '0.02'; # TRIAL
 }
 
 # ABSTRACT: Representation of a Virtual Machine in JiffyBox
 
 use Moo;
 use JSON;
-use LWP::UserAgent; # needed?
 
 has id         => (is => 'rw', required => 1);
-has hypervisor => (is => 'rw');
+has hypervisor => (is => 'rw', required => 1);
 
 has last          => (is => 'rw');
 has backup_cache  => (is => 'rw');
@@ -25,7 +24,7 @@ sub get_backups {
     my $url = $self->{hypervisor}->base_url . '/backups/' . $self->id;
     
     # POSSIBLE EXIT
-    return $url if ($self->{hypervisor}->test_mode);
+    return { url => $url } if ($self->{hypervisor}->test_mode);
     
     my $response = $self->{hypervisor}->ua->get($url);
 
@@ -52,7 +51,7 @@ sub get_details {
     
     # POSSIBLE EXIT
     # return the URL if we are using test_mode
-    return $url if ($self->{hypervisor}->test_mode);
+    return { url => $url } if ($self->{hypervisor}->test_mode);
     
     # send the request and return the response
     my $response = $self->{hypervisor}->ua->get($url);
@@ -74,19 +73,15 @@ sub get_details {
 sub start {
     my $self = shift;
     
-    my $url = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
+    my $url  = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
+    my $json = to_json( { status => 'START' } );
     
     # POSSIBLE EXIT
-    return $url if ($self->{hypervisor}->test_mode);
+    return { url => $url, json => $json }
+        if ($self->{hypervisor}->test_mode);
     
     # send the request with method specific json content
-    my $response = $self->{hypervisor}->ua->put(  $url,
-                                                  Content => to_json(
-                                                    {
-                                                      status => 'START'
-                                                    }
-                                                  )
-                                                );
+    my $response = $self->{hypervisor}->ua->put( $url, Content => $json ); 
 
     # POSSIBLE EXIT
     unless ($response->is_success) {
@@ -105,19 +100,15 @@ sub start {
 sub stop {
     my $self = shift;
     
-    my $url = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
+    my $url  = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
+    my $json = to_json( { status => 'SHUTDOWN' } );
     
     # POSSIBLE EXIT
-    return $url if ($self->{hypervisor}->test_mode);
+    return { url => $url, json => $json }
+        if ($self->{hypervisor}->test_mode);
     
-    my $response = $self->{hypervisor}->ua->put( $url,
-                                                 Content => to_json(
-                                                   {
-                                                     status => 'SHUTDOWN'
-                                                   }
-                                                 )
-                                               );
-        
+    my $response = $self->{hypervisor}->ua->put( $url, Content => $json ); 
+
     # POSSIBLE EXIT
     unless ($response->is_success) {
 
@@ -138,7 +129,7 @@ sub delete {
     my $url = $self->{hypervisor}->base_url . '/jiffyBoxes/' . $self->id;
     
     # POSSIBLE EXIT
-    return $url if ($self->{hypervisor}->test_mode);
+    return { url => $url } if ($self->{hypervisor}->test_mode);
     
     my $response = $self->{hypervisor}->ua->delete($url);    
 
@@ -168,7 +159,7 @@ VM::JiffyBox::Box - Representation of a Virtual Machine in JiffyBox
 
 =head1 VERSION
 
-version 0.007
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -176,19 +167,17 @@ This module should be used together with L<VM::JiffyBox>.
 L<VM::JiffyBox> is the factory for producing objects of this module.
 However if you want to do it yourself:
 
- my $box = VM::JiffyBox::Box->new(id => $box_id);
-
- # set the hypervisor of the VM (e.g. ref to JiffyBox)
- $box->hypervisor($ref);
+ my $box = VM::JiffyBox::Box->new(id => $box_id, hypervisor => $ref);
 
 You then can do a lot of stuff with this box:
 
  # get some info
- my $backup_id  = $box->get_backups()->{result}->{daily}->{id};
- my $plan_id    = $box->get_details()->{result}->{plan}->{id};
+ my $backup_id = $box->get_backups()->{result}->{daily}->{id};
+ my $plan_id   = $box->get_details()->{result}->{plan}->{id};
 
  # get more info using the caching technique
- my $state      = $box->last->{result}->{status}
+ my $state = $box->details_chache->{result}->{status};
+ my $ip    = $box->last->{result}->{ips}->{public}->[0];
  # ... or
  use Data::Dumper;
  print Dumper( $box->backup_cache->{result} );
@@ -248,6 +237,28 @@ Contains information of the last call to delete().
 
 =head1 METHODS
 
+All methods (exluding C<new>) will return information about the request, instead of doing a call to the API if the hypervisor is in C<test_mode>.
+
+=head2 new
+
+Creates a box-object.
+Requires two paramters.
+
+=over
+
+=item id
+
+C<ID> of the box.
+Required.
+See the official documentation of I<JiffyBox> for more information.
+
+=item hypervisor
+
+An object reference to C<VM::JiffyBox>.
+Required.
+
+=back
+
 =head2 get_details
 
 Returns hashref with information about the virtual machine.
